CliArgs class

Parsed command-line arguments.

Provides the raw parsed values from command-line arguments before conversion to TraversalInfo objects.

Constructors

CliArgs({String? scan, bool recursive = false, bool notRecursive = false, String? root, bool bareRoot = false, bool scanExplicitlySet = false, bool recursiveExplicitlySet = false, List<String> excludePatterns = const [], List<String> excludeProjects = const [], List<String> recursionExclude = const [], List<String> projectPatterns = const [], List<String> modes = const [], List<String> modules = const [], List<String> skipModules = const [], bool innerFirstGit = false, bool outerFirstGit = false, bool topRepo = false, bool buildOrder = true, bool excludeDev = false, bool workspaceRecursion = false, bool verbose = false, bool dryRun = false, bool listOnly = false, bool force = false, bool guide = false, bool dumpConfig = false, String? configPath, bool help = false, bool version = false, bool noSkip = false, bool nested = false, bool dumpDefinitions = false, String? completion, bool includeTestProjects = false, bool testProjectsOnly = false, List<String> positionalArgs = const [], List<String> commands = const [], Map<String, PerCommandArgs> commandArgs = const {}, Map<String, dynamic> extraOptions = const {}})
const

Properties

bareRoot bool
final
buildOrder bool
final
commandArgs Map<String, PerCommandArgs>
final
commands List<String>
final
completion String?
Requested shell for --completion <shell> (bash|zsh|fish), or null.
final
configPath String?
final
dryRun bool
final
dumpConfig bool
final
dumpDefinitions bool
final
effectiveRecursive bool
Whether effective recursive mode is on.
no setter
excludeDev bool
final
excludePatterns List<String>
final
excludeProjects List<String>
final
extraOptions Map<String, dynamic>
final
force bool
final
gitModeExplicitlySet bool
Whether git traversal mode is explicitly specified via CLI.
no setter
guide bool
final
hashCode int
The hash code for this object.
no setterinherited
help bool
final
includeTestProjects bool
final
innerFirstGit bool
final
isHelpMode bool
Whether this is a help-related mode (help, version, list, guide).
no setter
isHelpOrVersion bool
Whether help or version was requested.
no setter
listOnly bool
final
modes List<String>
final
modules List<String>
final
nested bool
final
noSkip bool
final
notRecursive bool
final
outerFirstGit bool
final
positionalArgs List<String>
final
projectPatterns List<String>
final
recursionExclude List<String>
final
recursive bool
final
recursiveExplicitlySet bool
final
root String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scan String?
final
scanExplicitlySet bool
final
skipModules List<String>
final
testProjectsOnly bool
final
topRepo bool
final
verbose bool
final
version bool
final
workspaceRecursion bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toGitTraversalInfo({String? executionRoot, GitTraversalOrder? commandDefaultGitOrder}) GitTraversalInfo?
Convert to GitTraversalInfo.
toProjectTraversalInfo({String? executionRoot, TraversalDefaults? configDefaults}) ProjectTraversalInfo
Convert to ProjectTraversalInfo.
toString() String
A string representation of this object.
inherited
withResolvedStrings(String resolver(String)) CliArgs
Create a copy with placeholders resolved in user-provided string values.

Operators

operator ==(Object other) bool
The equality operator.
inherited