without method
Return a new list with the named commands removed.
Implementation
List<CommandDefinition> without(Set<String> names) =>
where((c) => !names.contains(c.name)).toList();
Return a new list with the named commands removed.
List<CommandDefinition> without(Set<String> names) =>
where((c) => !names.contains(c.name)).toList();