DartExecutor class

Executor that invokes a Dart function for each project.

Inheritance

Constructors

DartExecutor({required Future<bool> dartFunction(CommandContext context), String successMessage(CommandContext context)?})

Properties

dartFunction Future<bool> Function(CommandContext context)
Dart function to execute.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
successMessage String Function(CommandContext context)?
Success message generator.
final

Methods

execute(CommandContext context, CliArgs args) Future<ItemResult>
Execute command on a single folder.
override
executeWithoutTraversal(CliArgs args) Future<ToolResult>
Execute command without traversal.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited