FolderContext class

A scanned folder with its detected natures.

Constructors

FolderContext({required FsFolder fsFolder, required List<RunFolder> natures})

Properties

fsFolder FsFolder
The underlying filesystem folder.
final
hashCode int
The hash code for this object.
no setterinherited
name String
Folder name.
no setter
natures List<RunFolder>
All natures detected for this folder.
final
path String
Path to the folder.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getNature<T extends RunFolder>() → T?
Get a specific nature, or null if not present.
hasNature<T extends RunFolder>() bool
Check if this folder has a specific nature.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited