FolderSorter class

Sorts folders based on traversal configuration.

Constructors

FolderSorter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sortByBuildOrder<T>(List<T> folders, String getPath(T), List<String> globalOrder) List<T>
Sort folders by dependency order (for project traversal).
sortByInnerFirst<T>(List<T> folders, String getPath(T)) List<T>
Sort git repos by inner-first order.
sortByOuterFirst<T>(List<T> folders, String getPath(T)) List<T>
Sort git repos by outer-first order.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited