HelpTopic class

A named help topic that can be shown via tool help <name>.

Constructors

HelpTopic({required String name, required String summary, required String content})
const

Properties

content String
Full help text (may include markdown-style formatting).
final
hashCode int
The hash code for this object.
no setterinherited
name String
Topic name (used in help <name>).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
summary String
Short description shown in the topics list.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited