PipelineDefinition class

Constructors

PipelineDefinition({bool executable = true, List<String> runBefore = const [], List<String> runAfter = const [], Map<String, String> globalOptions = const {}, List<PipelineStepConfig> precore = const [], List<PipelineStepConfig> core = const [], List<PipelineStepConfig> postcore = const []})
const

Properties

core List<PipelineStepConfig>
final
executable bool
final
globalOptions Map<String, String>
final
hashCode int
The hash code for this object.
no setterinherited
postcore List<PipelineStepConfig>
final
precore List<PipelineStepConfig>
final
runAfter List<String>
final
runBefore List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited