ScanResults class

Result of workspace scanning with nature detection.

Provides type-safe access to scanned folders by their nature.

Constructors

ScanResults(List<FolderContext> folders)

Properties

folders List<FolderContext>
All scanned folder contexts with their detected natures.
final
hashCode int
The hash code for this object.
no setterinherited
paths Iterable<String>
Get all folder paths.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

byNature<T extends RunFolder>() Iterable<T>
Get all folders that have a specific nature type.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withNature<T extends RunFolder>() Iterable<FolderContext>
Get all FolderContexts that have a specific nature type.

Operators

operator ==(Object other) bool
The equality operator.
inherited