TomBuildFolder class
Tom project configuration nature.
Detected when folder contains tom_project.yaml.
Constructors
Properties
-
config
→ Map<
String, dynamic> -
Raw config map from tom_project.yaml.
final
- fsFolder → FsFolder
-
The underlying filesystem folder.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Folder name (basename of path).
no setterinherited
- path → String
-
Absolute path to the folder.
no setterinherited
- projectName → String?
-
Project name from tom_project.yaml (e.g., "buildkit", "core-kernel").
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortId → String?
-
Short project ID from tom_project.yaml (e.g., "BK", "CK").
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
hasTomProjectYaml(
String dirPath) → bool - Check if a folder has tom_project.yaml.