TomBuildMasterFolder class

Tom build master configuration nature.

Detected when folder contains buildkit_master.yaml.

Inheritance

Constructors

TomBuildMasterFolder(FsFolder fsFolder, {Map<String, dynamic> config = const {}})

Properties

config Map<String, dynamic>
Raw config map from buildkit_master.yaml.
final
fsFolder FsFolder
The underlying filesystem folder.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
Folder name (basename of path).
no setterinherited
path String
Absolute path to the folder.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

hasTomMasterYaml(String dirPath) bool
Check if a folder has buildkit_master.yaml.