WiringResult class

Result of loading and resolving wired tool definitions.

Contains the dynamically-created CommandDefinitions and NestedToolExecutors for nested commands, ready to be merged into the host tool's command + executor maps.

Constructors

WiringResult({List<CommandDefinition> commands = const [], Map<String, NestedToolExecutor> executors = const {}, List<String> warnings = const [], List<String> errors = const []})
const

Properties

commands List<CommandDefinition>
New command definitions for wired commands.
final
errors List<String>
Errors (e.g., missing binaries in execution mode).
final
executors Map<String, NestedToolExecutor>
Executors keyed by host command name.
final
hasErrors bool
Whether any errors were encountered.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warnings List<String>
Warnings (e.g., missing binaries in help mode).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited