isWorkspaceBoundary function

bool isWorkspaceBoundary(
  1. String dirPath
)

Check if a directory is a workspace boundary (contains buildkit_master.yaml).

Workspace boundaries are treated similarly to skip markers — they mark directories that should be processed separately.

Implementation

bool isWorkspaceBoundary(String dirPath) {
  return File(p.join(dirPath, kBuildkitMasterYaml)).existsSync();
}