BuildBase class abstract

Main entry point for workspace traversal.

Provides static methods for scanning, filtering, and executing commands on folders across a workspace.

Constructors

BuildBase()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

findProjects({String scan = '.', bool recursive = true, List<String>? include, List<String>? exclude, Set<Type>? requiredNatures}) Future<List<CommandContext>>
Get list of projects without executing anything.
forEachDartProject(Future<bool> run(CommandContext ctx), {String scan = '.', bool recursive = true, List<String>? include, List<String>? exclude}) Future<ProcessingResult>
Convenience method to iterate over all Dart projects.
forEachGitRepo(Future<bool> run(CommandContext ctx), {GitTraversalMode mode = GitTraversalMode.innerFirst, List<String>? modules, List<String>? skipModules}) Future<ProcessingResult>
Convenience method to iterate over all git repositories.
traverse({required BaseTraversalInfo info, required Future<bool> run(CommandContext ctx), Set<Type>? requiredNatures, Set<Type> worksWithNatures = const {}, bool verbose = false}) Future<ProcessingResult>
Traverse folders and execute callback on each.