isDartProject property
bool
get
isDartProject
Check if this is a Dart project of any kind.
Implementation
bool get isDartProject => hasNature<DartProjectFolder>();
Check if this is a Dart project of any kind.
bool get isDartProject => hasNature<DartProjectFolder>();