CompletionGenerator class

Generates shell completion scripts from tool definitions.

Supports bash, zsh, and fish shells.

Constructors

CompletionGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateBash(ToolDefinition tool) String
Generate bash completion script.
generateFish(ToolDefinition tool) String
Generate fish completion script.
generateZsh(ToolDefinition tool) String
Generate zsh completion script.