OutputFormat enum

Supported CLI output formats.

Inheritance
Available extensions

Values

plain → const OutputFormat

Plain text (the default). Accepts the alias text.

csv → const OutputFormat

Comma-separated values.

json → const OutputFormat

JSON.

md → const OutputFormat

Markdown. Accepts the alias markdown.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

tryParse(String? value) OutputFormat?
Parses a format string (case-insensitive).

Constants

values → const List<OutputFormat>
A constant List of the values in this enum, in order of their declaration.