PerCommandArgs class

Per-command arguments for multi-command tools.

Constructors

PerCommandArgs({required String commandName, List<String> projectPatterns = const [], List<String> excludePatterns = const [], Map<String, dynamic> options = const {}})
const

Properties

commandName String
Command name (without : prefix).
final
excludePatterns List<String>
Command-specific exclude patterns.
final
hashCode int
The hash code for this object.
no setterinherited
options Map<String, dynamic>
Extra command-specific options.
final
projectPatterns List<String>
Command-specific project patterns.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited