SyncExecutor class

Synchronous callback-based executor.

For simple commands that don't need async operations.

Inheritance

Constructors

SyncExecutor({required ItemResult onExecute(CommandContext context, CliArgs args)})

Properties

hashCode int
The hash code for this object.
no setterinherited
onExecute ItemResult Function(CommandContext context, CliArgs args)
Synchronous callback.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(CommandContext context, CliArgs args) Future<ItemResult>
Execute command on a single folder.
override
executeWithoutTraversal(CliArgs args) Future<ToolResult>
Execute command without traversal.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited