ToolMode enum

Mode in which a tool can operate.

Inheritance
Available extensions

Values

multiCommand → const ToolMode

Multi-command tool like buildkit (supports :command syntax).

singleCommand → const ToolMode

Single-command tool.

hybrid → const ToolMode

Tool that can operate in both modes.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ToolMode>
A constant List of the values in this enum, in order of their declaration.