completion property
Requested shell for --completion <shell> (bash|zsh|fish), or null.
When set, the tool prints a shell completion script and exits without traversing or running any command.
Implementation
final String? completion;
Requested shell for --completion <shell> (bash|zsh|fish), or null.
When set, the tool prints a shell completion script and exits without traversing or running any command.
final String? completion;