GitRepoFinder class
Finds git repositories under a given root.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
findAll(
String root) → Future< List< FsFolder> > -
Find all git repositories under
rootrecursively. -
findTopRepo(
String startPath) → String? -
Find the topmost git repository by traversing up from
startPath. -
findWorkspaceRepos(
String root) → List< String> - Find git repositories at workspace level (shallow search).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited