HelpGenerator class
Generates help text from tool and command definitions.
Produces markdown-styled help output that can be rendered by console_markdown for ANSI-colored terminal output.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateCommandHelp(
CommandDefinition command, {ToolDefinition? tool}) → String - Generate command-level help text.
-
generateOptionHelp(
OptionDefinition option) → String - Generate option help for a single option.
-
generateToolHelp(
ToolDefinition tool, {Set< String> nestedCommandNames = const {}}) → String - Generate tool-level help text.
-
generateTopicHelp(
HelpTopic topic, {ToolDefinition? tool}) → String - Generate help text for a help topic.
-
generateUsageSummary(
ToolDefinition tool) → String - Generate a short usage summary for error messages.