NavigationFeatures class
Navigation features supported by a tool.
Constructors
-
const
Properties
- dryRun → bool
-
Whether tool supports dry-run mode.
final
- gitTraversal → bool
-
Whether tool supports git traversal.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interactiveMode → bool
-
Whether tool supports interactive mode.
final
- jsonOutput → bool
-
Whether tool supports JSON output.
final
- projectTraversal → bool
-
Whether tool supports project traversal.
final
- recursiveScan → bool
-
Whether tool supports recursive folder scanning.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verbose → bool
-
Whether tool supports verbose output.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- all → const NavigationFeatures
- All navigation features enabled.
- gitTool → const NavigationFeatures
- Default git tool features.
- minimal → const NavigationFeatures
- Minimal features (only verbose).
- projectTool → const NavigationFeatures
- Default project tool features.