UnresolvedPlaceholderException class
Exception thrown when a placeholder cannot be resolved.
- Implemented types
Constructors
- UnresolvedPlaceholderException(String placeholder, String folderPath, {String? message})
Properties
- folderPath → String
-
The folder path where resolution failed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
Optional additional message.
final
- placeholder → String
-
The placeholder name that couldn't be resolved.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited