VsCodeExtensionFolder class
VS Code extension nature.
Detected when folder contains package.json with VS Code extension fields.
Constructors
- VsCodeExtensionFolder(FsFolder fsFolder, {required String extensionName, String? version, String? displayName})
Properties
- displayName → String?
-
Extension display name.
final
- extensionName → String
-
Extension name from package.json.
final
- fsFolder → FsFolder
-
The underlying filesystem folder.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Folder name (basename of path).
no setterinherited
- path → String
-
Absolute path to the folder.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String?
-
Extension version.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
isVsCodeExtension(
String dirPath) → bool - Check if a folder is a VS Code extension.