WiringMode enum
Mode for how a nested tool is wired into a host tool.
Values
- multiCommand → const WiringMode
-
Multi-command tool (supports :command syntax).
Requires ToolWiringEntry.commands to specify the command mapping.
- standalone → const WiringMode
-
Standalone (single-command) tool.
The host command name defaults to the wiring entry key (or the binary name if no key override).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
WiringMode> - A constant List of the values in this enum, in order of their declaration.