CommandContext class
Context provided to commands during execution.
Contains the folder being processed, its detected natures, and traversal configuration.
Constructors
-
CommandContext({required FsFolder fsFolder, required List<
RunFolder> natures, required String executionRoot, BaseTraversalInfo? traversal})
Properties
- executionRoot → String
-
Execution root path.
final
- fsFolder → FsFolder
-
The scanned folder.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDartProject → bool
-
Check if this is a Dart project of any kind.
no setter
- isGitRepo → bool
-
Check if this is a git repository.
no setter
- name → String
-
Folder name.
no setter
-
natures
→ List<
RunFolder> -
Detected natures for this folder (GitFolder, DartProjectFolder, etc.).
final
- path → String
-
Absolute path to folder.
no setter
- relativePath → String
-
Relative path from execution root.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- traversal → BaseTraversalInfo?
-
Traversal configuration.
final
Methods
-
getNature<
T extends RunFolder> () → T - Get a specific nature (throws if not present).
-
hasNature<
T extends RunFolder> () → bool - Check if folder has a specific nature.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
tryGetNature<
T extends RunFolder> () → T? - Get a specific nature or null.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited