CommandExecutor class abstract
Base class for command executors.
Implement this to create custom command logic that integrates with the ToolRunner traversal system.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
execute(
CommandContext context, CliArgs args) → Future< ItemResult> - Execute command on a single folder.
-
executeWithoutTraversal(
CliArgs args) → Future< ToolResult> - Execute command without traversal.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited