FolderScanner class
Scans directories and builds a list of FsFolders.
Handles recursive scanning, skip markers, and recursion exclusions.
Constructors
- FolderScanner({String toolBasename = 'buildkit', bool verbose = false, bool ignoreSkipMarkers = false})
- Create a FolderScanner.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ignoreSkipMarkers → bool
-
When true, ignore all skip markers (workspace boundaries, *_skip.yaml)
and traverse into everything. Activated by
--no-skip.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipFilename → String
-
Tool-specific skip filename.
no setter
- toolBasename → String
-
Tool basename for tool-specific skip files (e.g., 'issuekit' → 'issuekit_skip.yaml').
final
- verbose → bool
-
Whether to print verbose messages for skipped directories.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scan(
String root, {bool recursive = false, List< String> recursionExclude = const []}) → Future<List< FsFolder> > -
Scan for folders starting from
root. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited