ProcessingResult class
Result of a traversal operation.
Constructors
Properties
- allSucceeded → bool
-
Whether all operations succeeded.
no setter
-
errors
→ Map<
String, Object> -
Paths that threw errors, with the error objects.
no setter
- failureCount → int
-
Number of failures (including errors).
no setter
-
failures
→ List<
String> -
Paths that failed processing (command returned false).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- successCount → int
-
Number of successful operations.
no setter
-
successes
→ List<
String> -
Paths that were processed successfully.
no setter
- total → int
-
Total number of folders processed.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recordError(
String path, Object error) → void -
recordFailure(
String path) → void -
recordSuccess(
String path) → void -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited