ShellExecutor class
Executor that runs a shell command in each folder.
- Inheritance
-
- Object
- CommandExecutor
- ShellExecutor
Constructors
- ShellExecutor({required String shellCommand, bool printOutput = true, String? workingDirectory})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- printOutput → bool
-
Whether to print command output.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shellCommand → String
-
Shell command to execute.
final
- workingDirectory → String?
-
Working directory override (null = use context.path).
final
Methods
-
execute(
CommandContext context, CliArgs args) → Future< ItemResult> -
Execute command on a single folder.
override
-
executeWithoutTraversal(
CliArgs args) → Future< ToolResult> -
Execute command without traversal.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited